@@ -6,11 +6,13 @@ The @balancesheet@ command prints a simple balance sheet.
 -}
 
 module Hledger.Cli.Balancesheet (
-  balancesheet
+  balancesheetmode
+ ,balancesheet
  ,tests_Hledger_Cli_Balancesheet
 ) where
 
 import qualified Data.Text.Lazy.IO as LT
+import System.Console.CmdArgs.Explicit
 import Test.HUnit
 import Text.Shakespeare.Text
 
@@ -19,6 +21,20 @@ import Hledger.Cli.Options
 import Hledger.Cli.Balance
 
 
+balancesheetmode :: Mode RawOpts
+balancesheetmode = (defCommandMode $ ["balancesheet"]++aliases) {
+  modeHelp = "show a balance sheet" `withAliases` aliases
+ ,modeGroupFlags = Group {
+     groupUnnamed = [
+      flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show accounts as a list"
+     ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "flat mode: omit N leading account name parts"
+     ]
+    ,groupHidden = []
+    ,groupNamed = [generalflagsgroup1]
+    }
+ }
+  where aliases = ["bs"]
+
 -- | Print a simple balance sheet.
 balancesheet :: CliOpts -> Journal -> IO ()
 balancesheet CliOpts{reportopts_=ropts} j = do
@@ -34,7 +50,6 @@ Assets:
 #{unlines $ balanceReportAsText ropts assetreport}
 Liabilities:
 #{unlines $ balanceReportAsText ropts liabilityreport}
-
 Total:
 --------------------
 #{padleft 20 $ showMixedAmountWithoutPrice total}
@@ -45,6 +60,7 @@ withoutBeginDate ropts@ReportOpts{..} = ropts{begin_=Nothing, period_=p}
   where p = case period_ of Nothing -> Nothing
                             Just (i, DateSpan _ e) -> Just (i, DateSpan Nothing e)
 
+tests_Hledger_Cli_Balancesheet :: Test
 tests_Hledger_Cli_Balancesheet = TestList
  [
  ]
