@@ -9,11 +9,13 @@ cash flows.)
 -}
 
 module Hledger.Cli.Cashflow (
-  cashflow
+  cashflowmode
+ ,cashflow
  ,tests_Hledger_Cli_Cashflow
 ) where
 
 import qualified Data.Text.Lazy.IO as LT
+import System.Console.CmdArgs.Explicit
 import Test.HUnit
 import Text.Shakespeare.Text
 
@@ -22,6 +24,19 @@ import Hledger.Cli.Options
 import Hledger.Cli.Balance
 
 
+cashflowmode :: Mode RawOpts
+cashflowmode = (defCommandMode ["cashflow","cf"]) {
+  modeHelp = "show a cashflow statement" `withAliases` ["cf"]
+ ,modeGroupFlags = Group {
+     groupUnnamed = [
+      flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show accounts as a list"
+     ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "flat mode: omit N leading account name parts"
+     ]
+    ,groupHidden = []
+    ,groupNamed = [generalflagsgroup1]
+    }
+ }
+
 -- | Print a simple cashflow statement.
 cashflow :: CliOpts -> Journal -> IO ()
 cashflow CliOpts{reportopts_=ropts} j = do
@@ -37,12 +52,12 @@ cashflow CliOpts{reportopts_=ropts} j = do
 
 Cash flows:
 #{unlines $ balanceReportAsText ropts cashreport}
-
 Total:
 --------------------
 #{padleft 20 $ showMixedAmountWithoutPrice total}
 |]
 
+tests_Hledger_Cli_Cashflow :: Test
 tests_Hledger_Cli_Cashflow = TestList
  [
  ]
