@@ -6,11 +6,13 @@ The @incomestatement@ command prints a simple income statement (profit & loss) r
 -}
 
 module Hledger.Cli.Incomestatement (
-  incomestatement
+  incomestatementmode
+ ,incomestatement
  ,tests_Hledger_Cli_Incomestatement
 ) where
 
 import qualified Data.Text.Lazy.IO as LT
+import System.Console.CmdArgs.Explicit
 import Test.HUnit
 import Text.Shakespeare.Text
 
@@ -18,6 +20,21 @@ import Hledger
 import Hledger.Cli.Options
 import Hledger.Cli.Balance
 
+
+incomestatementmode :: Mode RawOpts
+incomestatementmode = (defCommandMode $ ["incomestatement"]++aliases) {
+  modeHelp = "show an income statement" `withAliases` aliases
+ ,modeGroupFlags = Group {
+     groupUnnamed = [
+      flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show accounts as a list"
+     ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "flat mode: omit N leading account name parts"
+     ]
+    ,groupHidden = []
+    ,groupNamed = [generalflagsgroup1]
+    }
+ }
+  where aliases = ["is"]
+
 -- | Print a simple income statement.
 incomestatement :: CliOpts -> Journal -> IO ()
 incomestatement CliOpts{reportopts_=ropts} j = do
@@ -32,7 +49,6 @@ Revenues:
 #{unlines $ balanceReportAsText ropts incomereport}
 Expenses:
 #{unlines $ balanceReportAsText ropts expensereport}
-
 Total:
 --------------------
 #{padleft 20 $ showMixedAmountWithoutPrice total}
