@@ -5,7 +5,8 @@ A ledger-compatible @register@ command.
 -}
 
 module Hledger.Cli.Register (
-  register
+  registermode
+ ,register
  ,postingsReportAsText
  -- ,showPostingWithBalanceForVty
  ,tests_Hledger_Cli_Register
@@ -13,6 +14,7 @@ module Hledger.Cli.Register (
 
 import Data.List
 import Data.Maybe
+import System.Console.CmdArgs.Explicit
 import Test.HUnit
 import Text.Printf
 
@@ -22,6 +24,21 @@ import Hledger.Utils.UTF8IOCompat (putStr)
 import Hledger.Cli.Options
 
 
+registermode = (defCommandMode $ ["register"] ++ aliases) {
+  modeHelp = "show postings and running total" `withAliases` aliases
+ ,modeGroupFlags = Group {
+     groupUnnamed = [
+      flagNone ["historical","H"] (\opts -> setboolopt "historical" opts) "include prior postings in the running total"
+     ,flagNone ["average","A"] (\opts -> setboolopt "average" opts) "show a running average instead of the running total"
+     ,flagNone ["related","r"] (\opts -> setboolopt "related" opts) "show postings' siblings instead"
+     ,flagOpt (show defaultWidthWithFlag) ["width","w"] (\s opts -> Right $ setopt "width" s opts) "N" "set output width to 120, or N (default: 80)"
+     ]
+    ,groupHidden = []
+    ,groupNamed = [generalflagsgroup1]
+    }
+ }
+  where aliases = ["reg"]
+
 -- | Print a (posting) register report.
 register :: CliOpts -> Journal -> IO ()
 register opts@CliOpts{reportopts_=ropts} j = do
